@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.2.2
+# Version   : 0.2.3
 
 import  numpy                   as      np
 import  plotly.graph_objects    as      go
@@ -549,15 +549,14 @@ class AFM:
 
             if self.file_name[-3:] != 'nid':
                 _z = self.z_position_raw[:,curve_number]
-                piezo_position = np.concatenate((_z, _z), axis = 0)
 
             if approach_dev < max_approach_noise and retract_dev < max_retract_noise:
                 self.approach[:,i] = adjusted_approach
                 self.retract[:,i] = adjusted_retract
 
                 if self.file_name[-3:] != 'nid':
-                    self.z_approach[:,i] = piezo_position
-                    self.z_withdraw[:,i] = piezo_position
+                    self.z_approach[:,i] = _z
+                    self.z_withdraw[:,i] = _z
 
                 i += 1
 
